﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace MusicLibrary
{
    public partial class MainForm : Form
    {
        public MainForm()
        {
            InitializeComponent();
        }

        private void quitToolStripMenuItem_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void newSongToolStripMenuItem_Click(object sender, EventArgs e)
        {
            NewSongDialog diag = new NewSongDialog();

            if (diag.ShowDialog() == DialogResult.OK)
            {
                songListBox.Items.Add(diag.Song);
            }
        }

        private void saveToolStripMenuItem_Click(object sender, EventArgs e)
        {
            SaveFileDialog diag = new SaveFileDialog();

            diag.DefaultExt = "mml";
            diag.AddExtension = true;
            diag.Filter = "My Music Library|*.mml";

            if (diag.ShowDialog() == DialogResult.OK)
            {
                try
                {
                    using (StreamWriter sw = new StreamWriter(diag.FileName))
                    {
                        foreach (Song song in songListBox.Items.Cast<Song>())
                        {
                            sw.WriteLine("{0};{1};{2}", song.Name, song.Artist, (int)song.Rating);
                        }
                    }
                }
                catch (IOException) { }
            }
        }

        private void loadToolStripMenuItem_Click(object sender, EventArgs e)
        {
            OpenFileDialog diag = new OpenFileDialog();

            diag.Filter = "My Music Library|*.mml";

            if (diag.ShowDialog() == DialogResult.OK)
            {
                songListBox.Items.Clear();

                try
                {
                    using (StreamReader sr = new StreamReader(diag.FileName))
                    {
                        string line;
                        while ((line = sr.ReadLine()) != null)
                        {
                            string[] props = line.Split(';');

                            Song song = new Song()
                                {
                                    Name = props[0],
                                    Artist = props[1],
                                    Rating = (Rating)Int32.Parse(props[2])
                                };

                            songListBox.Items.Add(song);
                        }
                    }
                }
                catch (IOException) { }
            }
        }
    }
}
